GroupRecord

Struct GroupRecord 

pub struct GroupRecord {
Show 16 fields pub group_name: String, pub uuid: Option<String>, pub realm: Option<String>, pub description: Option<String>, pub disposition: GroupDisposition, pub service: Option<String>, pub last_change_usec: Option<u64>, pub gid: Option<u32>, pub members: Option<Vec<String>>, pub administrators: Option<Vec<String>>, pub privileged: Option<GroupPrivileged>, pub per_machine: Option<Vec<GroupPerMachine>>, pub binding: Option<HashMap<String, GroupBinding>>, pub status: Option<HashMap<String, GroupStatus>>, pub signature: Option<Vec<GroupSignature>>, pub secret: Option<GroupSecret>,
}
Group Records

For a detailed explanation please visit https://systemd.io/GROUP_RECORDS

Fields

group_name: String

The UNIX group name for this record.

uuid: Option<String>

A string containing a lowercase UUID that identifies this group.

realm: Option<String>

The ‘realm’ a group is defined in.

description: Option<String>

A descriptive string for the group.

disposition: GroupDisposition

Clarifies the disposition of the group, i.e. the context it is defined in.

service: Option<String>

The service that defines or manages this group record.

last_change_usec: Option<u64>

A timestamp indicating when the group record was last changed (µs since the epoch 1970).

gid: Option<u32>

The numeric UNIX group ID (GID) to use for the group.

members: Option<Vec<String>>

An array of strings, listing user names that are members of this group.

administrators: Option<Vec<String>>

An array of strings, listing user names that shall be considered “administrators” of this group.

privileged: Option<GroupPrivileged>per_machine: Option<Vec<GroupPerMachine>>binding: Option<HashMap<String, GroupBinding>>status: Option<HashMap<String, GroupStatus>>signature: Option<Vec<GroupSignature>>secret: Option<GroupSecret>