pub struct GroupRecord {Show 16 fields
pub group_name: String,
pub uuid: Option<String>,
pub realm: Option<String>,
pub description: Option<String>,
pub disposition: GroupDisposition,
pub service: Option<String>,
pub last_change_usec: Option<u64>,
pub gid: Option<u32>,
pub members: Option<Vec<String>>,
pub administrators: Option<Vec<String>>,
pub privileged: Option<GroupPrivileged>,
pub per_machine: Option<Vec<GroupPerMachine>>,
pub binding: Option<HashMap<String, GroupBinding>>,
pub status: Option<HashMap<String, GroupStatus>>,
pub signature: Option<Vec<GroupSignature>>,
pub secret: Option<GroupSecret>,
}Expand description
Group Records
For a detailed explanation please visit https://systemd.io/GROUP_RECORDS
Fields
group_name: StringThe UNIX group name for this record.
uuid: Option<String>A string containing a lowercase UUID that identifies this group.
realm: Option<String>The ‘realm’ a group is defined in.
description: Option<String>A descriptive string for the group.
disposition: GroupDispositionClarifies the disposition of the group, i.e. the context it is defined in.
service: Option<String>The service that defines or manages this group record.
last_change_usec: Option<u64>A timestamp indicating when the group record was last changed (µs since the epoch 1970).
gid: Option<u32>The numeric UNIX group ID (GID) to use for the group.
members: Option<Vec<String>>An array of strings, listing user names that are members of this group.
administrators: Option<Vec<String>>An array of strings, listing user names that shall be considered “administrators” of this group.
privileged: Option<GroupPrivileged>per_machine: Option<Vec<GroupPerMachine>>binding: Option<HashMap<String, GroupBinding>>status: Option<HashMap<String, GroupStatus>>signature: Option<Vec<GroupSignature>>secret: Option<GroupSecret>Trait Implementations
Sourceimpl Debug for GroupRecordwhere
String: Debug,
Option<String>: Debug,
GroupDisposition: Debug,
Option<u64>: Debug,
Option<u32>: Debug,
Option<Vec<String>>: Debug,
Option<GroupPrivileged>: Debug,
Option<Vec<GroupPerMachine>>: Debug,
Option<HashMap<String, GroupBinding>>: Debug,
Option<HashMap<String, GroupStatus>>: Debug,
Option<Vec<GroupSignature>>: Debug,
Option<GroupSecret>: Debug,
impl Debug for GroupRecordwhere
String: Debug,
Option<String>: Debug,
GroupDisposition: Debug,
Option<u64>: Debug,
Option<u32>: Debug,
Option<Vec<String>>: Debug,
Option<GroupPrivileged>: Debug,
Option<Vec<GroupPerMachine>>: Debug,
Option<HashMap<String, GroupBinding>>: Debug,
Option<HashMap<String, GroupStatus>>: Debug,
Option<Vec<GroupSignature>>: Debug,
Option<GroupSecret>: Debug,
Sourceimpl Default for GroupRecordwhere
String: Default,
Option<String>: Default,
Option<u64>: Default,
Option<u32>: Default,
Option<Vec<String>>: Default,
Option<GroupPrivileged>: Default,
Option<Vec<GroupPerMachine>>: Default,
Option<HashMap<String, GroupBinding>>: Default,
Option<HashMap<String, GroupStatus>>: Default,
Option<Vec<GroupSignature>>: Default,
Option<GroupSecret>: Default,
impl Default for GroupRecordwhere
String: Default,
Option<String>: Default,
Option<u64>: Default,
Option<u32>: Default,
Option<Vec<String>>: Default,
Option<GroupPrivileged>: Default,
Option<Vec<GroupPerMachine>>: Default,
Option<HashMap<String, GroupBinding>>: Default,
Option<HashMap<String, GroupStatus>>: Default,
Option<Vec<GroupSignature>>: Default,
Option<GroupSecret>: Default,
Sourceimpl<'de> Deserialize<'de> for GroupRecord
impl<'de> Deserialize<'de> for GroupRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for GroupRecord
impl Display for GroupRecord
Sourceimpl TryFrom<Value> for GroupRecord
impl TryFrom<Value> for GroupRecord